@@ -328,9 +328,11 @@ genblockfunciter(int n, gpfunc *gp)
     gpm=gengerepile(bl2);
   if (tv==Gnotype)
   {
+    gpdescarg *dv;
     tree[vprime].t = iter->type;
-    gpdescarg *da=descfindrules(1, &vprime, lfunc+iter->next);
-    tv = da->type;
+    dv=descfindrules(1, &vprime, lfunc+iter->next);
+    if (!dv) die(n, "no suitable iterator_next found");
+    tv = dv->type;
   }
   pushvar(var,1<<Cuser|1<<Ccompo,tv,-1);
   lab=makesubblock_label(seq,Lbreak);
@@ -338,7 +340,7 @@ genblockfunciter(int n, gpfunc *gp)
     seq=newseq(seq,newcall("_label",newsmall(lab.ne)));
   if (autogc)
     seq=addseqright(seq,newcall("_gerepilemany",gpm));
-  cseq=newnode(Fassign,var,newcall(next,vprime));
+  cseq=newnode1(Fassign,var,newcall(next,vprime));
   tree[cseq].m=Mparens;
   aseq=addseqright(aseq,newcall("_whilenull",newnode(Flistarg,cseq,seq)));
   if (lab.go)
@@ -539,7 +541,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       seq=newseq(seq,newcall("_label",newsmall(lab.ne)));
     if (autogc)
       seq=addseqright(seq,newcall("_gerepilemany",gpm));
-    arg[0]=newnode(Fassign,var,vinf);
+    arg[0]=newnode1(Fassign,var,vinf);
     arg[1]=newopcall(OPle,newleaf(var),vsup);
     arg[2]=seq;
     arg[3]=newopcall(OPpp,newleaf(var),-1);
@@ -574,7 +576,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       bl2=newblock();
       if (autogc)
         gpm=gengerepile(bl2);
-      next = newnode(Fassign,newleaf(var),newnode(Ftag,
+      next = newnode1(Fassign,newleaf(var),newnode(Ftag,
             newcall("_call_GG",newnode(Flistarg,newnode(Flistarg,
                   newleaf(vfvnext),newleaf(vfvdat)),newleaf(var))),Gvec));
       lab=makesubblock_label(seq,Lbreak);
@@ -592,15 +594,19 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       makeblocks3(bl0,bl1,bl2,n,bseq,aseq,ret,sav0,savx);
     }
     break;
+  case GPfordivfactored:
   case GPfordiv:
     {
       int vdiv,div;
       int vloop;
+      int factored = gp->spec == GPfordivfactored;
+      int vt = factored ? Gvec: Gint;
       nb=genlistargs(n,arg,3,3);
       seq=arg[2];
       checkisvar(arg[1],gp->gpname,&var,&tv);
       newdecl(1<<Cconst,Gvec,-1,&vdiv);
-      div=newcall("divisors",arg[0]);
+      div=newcall("divisors", factored ?
+          newnode(Flistarg, arg[0], newsmall(1)) : arg[0]);
       bseq=addseqright(bseq,geninsertvar(div,vdiv));
       genblock(bseq,-1);
       savx=s_ctx.n;
@@ -609,7 +615,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       if (autogc)
         gpm=gengerepile(bl2);
       newdecl(0,Gsmall,-1,&vloop);
-      if (tv==Gnotype) tv=Gint;
+      if (tv==Gnotype) tv = vt;
       pushvar(var,1<<Cuser,tv,-1);
       lab=makesubblock_label(seq,Lbreak);
       if (lab.ne)
@@ -617,10 +623,10 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       if (autogc)
         seq=addseqright(seq,newcall("_gerepilemany",gpm));
       seq=addseqleft(
-          newnode(Fassign,newleaf(var),
+          newnode1(Fassign,newleaf(var),
             newnode(Ftag,
-              newcoeff(newleaf(vdiv),newleaf(vloop),-1),Gint)),seq);
-      arg[0]=newnode(Fassign,vloop,newsmall(1));
+              newcoeff(newleaf(vdiv),newleaf(vloop),-1), vt)),seq);
+      arg[0]=newnode1(Fassign,vloop,newsmall(1));
       arg[1]=newopcall(OPle,newleaf(vloop),newcall("length",vdiv));
       arg[2]=seq;
       arg[3]=newopcall(OPpp,newleaf(vloop),-1);
@@ -651,7 +657,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
         newdecl((1<<Cauto)|(1<<Cconst),Gsmall,-1,&vindex);
         newdecl((1<<Cauto)|(1<<Cconst),Gsmall,-1,&lstep);
         bseq=addseqright(bseq,geninsertvar(newcall("length",newleaf(vstep)),newleaf(lstep)));
-        sarg[0] = newnode(Fassign,newleaf(vindex),newsmall(1));
+        sarg[0] = newnode1(Fassign,newleaf(vindex),newsmall(1));
         sarg[1] = newleaf(lstep);
         sarg[2] = newnode(Fmatcoeff,newleaf(vstep),
             newnode(Fmatrix,newnode(Frange,newleaf(vindex),GNORANGE),-1));
@@ -687,7 +693,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
         seq=newseq(seq,newcall("_label",newsmall(lab.ne)));
       if (autogc)
         seq=addseqright(seq,newcall("_gerepilemany",gpm));
-      arg[0]=newnode(Fassign,var,vinf);
+      arg[0]=newnode1(Fassign,var,vinf);
       if ( !dosign )
       {
         if ( tree[bstep].x>0 )
@@ -769,7 +775,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       if (bsup==GNOARG) nbs=2; else args[2]=vsup;
       aseq=addseqleft(newcall((tv==Gsmall?"_u_forprime_init":"_forprime_init"),
             stacktoargs(args,nbs)),aseq);
-      bseq=newnode(Fassign,var,newcall(tv==Gsmall?"_u_forprime_next":"_forprime_next_",vprime));
+      bseq=newnode1(Fassign,var,newcall(tv==Gsmall?"_u_forprime_next":"_forprime_next_",vprime));
       tree[bseq].m=Mparens;
       aseq=addseqright(aseq,newcall("_whilenull",newnode(Flistarg,bseq,seq)));
     }
@@ -826,7 +832,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
     makesubblock_label(seq,Lnobrk);
     if (autogc)
       seq=addseqright(seq,newcall("_gerepilemany",gpm));
-    arg[0]=newnode(Fassign,var,vinf);
+    arg[0]=newnode1(Fassign,var,vinf);
     arg[1]=newopcall(OPle,newleaf(var),vsup);
     arg[2]=seq;
     arg[3]=newopcall(OPpp,newleaf(var),-1);
@@ -859,10 +865,10 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       if (autogc)
         seq=addseqright(seq,newcall("_gerepilemany",gpm));
       seq=addseqleft(
-          newnode(Fassign,newleaf(var),
+          newnode1(Fassign,newleaf(var),
             newnode(Ftag,
               newcoeff(newleaf(vdiv),newleaf(vloop),-1),Gint)),seq);
-      arg[0]=newnode(Fassign,vloop,newsmall(1));
+      arg[0]=newnode1(Fassign,vloop,newsmall(1));
       arg[1]=newopcall(OPle,newleaf(vloop),newcall("length",vdiv));
       arg[2]=seq;
       arg[3]=newopcall(OPpp,newleaf(vloop),-1);
@@ -916,7 +922,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       newdecl(0,Gsmall,-1,&var);
     aseq=addseqright(aseq,newgetg(ret,newleaf(vsup),
           gp->spec==GPvector?"t_VEC":gp->spec==GPvectorv?"t_COL":"t_VECSMALL"));
-    arg[0]=newnode(Fassign,var,newsmall(1));
+    arg[0]=newnode1(Fassign,var,newsmall(1));
     arg[1]=newopcall(OPle,newleaf(var),vsup);
     arg[2]=newcoeff(newleaf(ret),newleaf(var),-1);
     arg[2]=geninsertvar(seq,arg[2]);
@@ -960,7 +966,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
         seq=arg[4];
       aseq=newgetg(newcoeff(newleaf(ret),newleaf(var1),-1),
           newleaf(vsup2),"t_COL");
-      arg[0]=newnode(Fassign,var2,newsmall(1));
+      arg[0]=newnode1(Fassign,var2,newsmall(1));
       arg[1]=newopcall(OPle,newleaf(var2),vsup2);
       arg[3]=newopcall(OPpp,newleaf(var2),-1);
       arg[2]=newcoeff(newleaf(ret),newleaf(var2),newleaf(var1));
@@ -968,7 +974,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       makesubblock_label(arg[2],Lnobrk);
       arg[2]=addseqright(aseq,newcall("for",stacktoargs(arg,4)));
       aseq=newgetg(ret,newleaf(vsup1),"t_MAT");
-      arg[0]=newnode(Fassign,var1,newsmall(1));
+      arg[0]=newnode1(Fassign,var1,newsmall(1));
       arg[1]=newopcall(OPle,newleaf(var1),vsup1);
       arg[3]=newopcall(OPpp,newleaf(var1),-1);
       aseq=addseqright(aseq,newcall("for",stacktoargs(arg,4)));
@@ -1003,7 +1009,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       sprintf(buf,"prec%d",++preclevel);
       vn = newnode(Fentry, newentry(strdup(buf)), -1);
       pushvar(vn, (1<<Cuser), Gsmall, -1);
-      y = newnode(Fassign, vn, newcall("_ndec2prec", y));
+      y = newnode1(Fassign, vn, newcall("_ndec2prec", y));
       genblock(y, n);
       tree[n].y = y;
     }
@@ -1015,7 +1021,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       sprintf(buf,"bitprec%d",++preclevel);
       vn = newnode(Fentry, newentry(strdup(buf)), -1);
       pushvar(vn, (1<<Cuser), Gsmall, -1);
-      y = newnode(Fassign, vn, newcall("_ndec2nbits", y));
+      y = newnode1(Fassign, vn, newcall("_ndec2nbits", y));
       genblock(y, n);
       tree[n].y = y;
     }
@@ -1261,6 +1267,10 @@ int gentypefuncspec(int n, gpfunc *gp)
     gentype(y);
     tree[n].m=(tree[y].m&MODHERIT)|(1<<Msidef);
     return Gvec;
+  case GPmakevecsmall:
+    gentype(y);
+    tree[n].m=(tree[y].m&MODHERIT)|(1<<Msidef);
+    return Gvecsmall;
   case GPclosure:
     nb=genlistargs(n,arg,1,STACKSZ);
     gentypemode(nb,arg,&tree[n].m);
@@ -1544,6 +1554,7 @@ void genentryspec(FILE *fout, int n, gpfunc *gp)
     fprintf(fout,")\n");
     genbrace(fout,arg[1]);
     break;
+  case GPmakevecsmall:
   case GPmakevec:
     nb=genlistargs(n,arg,1,STACKSZ);
     genindent(fout);
