@@ -565,20 +565,20 @@ void genblockaffmatrixl(int n, int x, int y, int z)
   aseq=newcall("for",stacktoargs(arg,4));
   makeblocks(bl1,bl2,n,bseq,aseq,vz,savx);
 }
-void genblockvector(int n, const char *typ)
+void genblockvector(int n, int t, const char *typ)
 {
   int arg[STACKSZ];
   int x=tree[n].x;
   int i,nb,ret;
   int aseq;
   nb=listtostack(x,Fmatrixelts,arg+1,STACKSZ-1,"Vector too long.",n);
-  newdecl(0,Gvec,-1,&ret);
+  newdecl(0,t,-1,&ret);
   arg[0]=newgetg(ret, newsmall(nb), typ);
   for(i=1;i<=nb;i++)
     arg[i]=geninsertvar(arg[i],newvectoridx(newleaf(ret),i));
   for(i=1;i<=nb;i++)
     genblock(arg[i],-1);
-  aseq=newcall("_makevec",stacktoargs(arg,nb+1));
+  aseq=newcall(t==Gvec?"_makevec":"_makevecsmall",stacktoargs(arg,nb+1));
   makeblock(newblock(),n,aseq,ret,s_ctx.n);
 }
 void genblockindex(int n)
@@ -782,7 +782,7 @@ void genblock(int n, int p)
         tree[n]=tree[z];
       }
       else
-        genblockvector(n, "t_VEC");
+        genblockvector(n, Gvec, "t_VEC");
     break;
   case Fassign:
     x=detag(x);
@@ -942,9 +942,23 @@ void genblock(int n, int p)
       else
       {
         tree[n]=tree[y];
-        genblockvector(n,"t_COL");
+        genblockvector(n,Gvec,"t_COL");
       }
     }
+    else if(strcmp(value[x].val.str,"Vecsmall")==0 && tree[y].f==Fvec)
+    {
+      if (tree[y].x==-1)
+      {
+        int z=newgetgvec("t_VECSMALL");
+        tree[n]=tree[z];
+      }
+      else
+      {
+        tree[n]=tree[y];
+        genblockvector(n,Gvecsmall,"t_VECSMALL");
+      }
+
+    }
     else
     {
       int nf=findfunction(value[x].val.str);
