@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -113,8 +113,8 @@ static int newcommand(int x, int y)
 
 /* In a future release of Bison, this section will be replaced
    by #include "y.tab.h".  */
-#ifndef YY_YY_Y_TAB_H_INCLUDED
-# define YY_YY_Y_TAB_H_INCLUDED
+#ifndef YY_YY_PARSE_H_INCLUDED
+# define YY_YY_PARSE_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -202,7 +202,7 @@ extern int yydebug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE YYSTYPE;
+
 union YYSTYPE
 {
 #line 32 "parse.y" /* yacc.c:355  */
@@ -212,6 +212,8 @@ union YYSTYPE
 
 #line 214 "parse.c" /* yacc.c:355  */
 };
+
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
 #endif
@@ -221,11 +223,11 @@ extern YYSTYPE yylval;
 
 int yyparse (void);
 
-#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
+#endif /* !YY_YY_PARSE_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-#line 229 "parse.c" /* yacc.c:358  */
+#line 231 "parse.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -1548,660 +1550,660 @@ yyreduce:
         case 2:
 #line 91 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 1552 "parse.c" /* yacc.c:1646  */
+#line 1554 "parse.c" /* yacc.c:1646  */
     break;
 
   case 3:
 #line 92 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newcommand((yyvsp[-2].val),(yyvsp[0].val));}
-#line 1558 "parse.c" /* yacc.c:1646  */
+#line 1560 "parse.c" /* yacc.c:1646  */
     break;
 
   case 4:
 #line 95 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=GNOARG;}
-#line 1564 "parse.c" /* yacc.c:1646  */
+#line 1566 "parse.c" /* yacc.c:1646  */
     break;
 
   case 5:
 #line 96 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 1570 "parse.c" /* yacc.c:1646  */
+#line 1572 "parse.c" /* yacc.c:1646  */
     break;
 
   case 6:
 #line 97 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[-1].val);}
-#line 1576 "parse.c" /* yacc.c:1646  */
+#line 1578 "parse.c" /* yacc.c:1646  */
     break;
 
   case 7:
 #line 98 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newcommand((yyvsp[-2].val),(yyvsp[0].val));}
-#line 1582 "parse.c" /* yacc.c:1646  */
+#line 1584 "parse.c" /* yacc.c:1646  */
     break;
 
   case 8:
 #line 101 "parse.y" /* yacc.c:1646  */
     { (yyval.val)=newnode(Frange,GNORANGE,GNORANGE); }
-#line 1588 "parse.c" /* yacc.c:1646  */
+#line 1590 "parse.c" /* yacc.c:1646  */
     break;
 
   case 9:
 #line 102 "parse.y" /* yacc.c:1646  */
     { (yyval.val)=newnode(Frange,(yyvsp[0].val),GNORANGE); }
-#line 1594 "parse.c" /* yacc.c:1646  */
+#line 1596 "parse.c" /* yacc.c:1646  */
     break;
 
   case 10:
 #line 103 "parse.y" /* yacc.c:1646  */
     { (yyval.val)=newnode(Frange,(yyvsp[-2].val),(yyvsp[0].val)); }
-#line 1600 "parse.c" /* yacc.c:1646  */
+#line 1602 "parse.c" /* yacc.c:1646  */
     break;
 
   case 11:
 #line 104 "parse.y" /* yacc.c:1646  */
     { (yyval.val)=newnode(Frange,GNORANGE,(yyvsp[0].val)); }
-#line 1606 "parse.c" /* yacc.c:1646  */
+#line 1608 "parse.c" /* yacc.c:1646  */
     break;
 
   case 12:
 #line 107 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fmatrix,(yyvsp[-3].val),(yyvsp[-1].val));}
-#line 1612 "parse.c" /* yacc.c:1646  */
+#line 1614 "parse.c" /* yacc.c:1646  */
     break;
 
   case 13:
 #line 108 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fmatrix,(yyvsp[-1].val),-1);}
-#line 1618 "parse.c" /* yacc.c:1646  */
+#line 1620 "parse.c" /* yacc.c:1646  */
     break;
 
   case 14:
 #line 111 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=1;}
-#line 1624 "parse.c" /* yacc.c:1646  */
+#line 1626 "parse.c" /* yacc.c:1646  */
     break;
 
   case 15:
 #line 112 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[-1].val)+1;}
-#line 1630 "parse.c" /* yacc.c:1646  */
+#line 1632 "parse.c" /* yacc.c:1646  */
     break;
 
   case 16:
 #line 115 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPhist,-1,-1);}
-#line 1636 "parse.c" /* yacc.c:1646  */
+#line 1638 "parse.c" /* yacc.c:1646  */
     break;
 
   case 17:
 #line 116 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPhist,newintnode((yyvsp[0].str).s,(yyvsp[0].str).c),-1);}
-#line 1642 "parse.c" /* yacc.c:1646  */
+#line 1644 "parse.c" /* yacc.c:1646  */
     break;
 
   case 18:
 #line 117 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPhist,newnode(Fsmall,-(yyvsp[0].val),-1),-1);}
-#line 1648 "parse.c" /* yacc.c:1646  */
+#line 1650 "parse.c" /* yacc.c:1646  */
     break;
 
   case 19:
 #line 118 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPhisttime,-1,-1);}
-#line 1654 "parse.c" /* yacc.c:1646  */
+#line 1656 "parse.c" /* yacc.c:1646  */
     break;
 
   case 20:
 #line 119 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPhisttime,newintnode((yyvsp[0].str).s,(yyvsp[0].str).c),-1);}
-#line 1660 "parse.c" /* yacc.c:1646  */
+#line 1662 "parse.c" /* yacc.c:1646  */
     break;
 
   case 21:
 #line 120 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPhisttime,newnode(Fsmall,-(yyvsp[0].val),-1),-1);}
-#line 1666 "parse.c" /* yacc.c:1646  */
+#line 1668 "parse.c" /* yacc.c:1646  */
     break;
 
   case 22:
 #line 126 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newintnode((yyvsp[0].str).s,(yyvsp[0].str).c);}
-#line 1672 "parse.c" /* yacc.c:1646  */
+#line 1674 "parse.c" /* yacc.c:1646  */
     break;
 
   case 23:
 #line 127 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newrealnode((yyvsp[0].str).s,(yyvsp[0].str).c);}
-#line 1678 "parse.c" /* yacc.c:1646  */
+#line 1680 "parse.c" /* yacc.c:1646  */
     break;
 
   case 24:
 #line 128 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fconst,newsmallrealvalue(0),-1);}
-#line 1684 "parse.c" /* yacc.c:1646  */
+#line 1686 "parse.c" /* yacc.c:1646  */
     break;
 
   case 25:
 #line 129 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnodecom(Ffunction,newmember((yyvsp[0].str).s),newintnode((yyvsp[-2].str).s,(yyvsp[-2].str).c),
                                                    (yyvsp[0].str).c);}
-#line 1691 "parse.c" /* yacc.c:1646  */
+#line 1693 "parse.c" /* yacc.c:1646  */
     break;
 
   case 26:
 #line 131 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newstringnode((yyvsp[0].str).s,(yyvsp[0].str).c);}
-#line 1697 "parse.c" /* yacc.c:1646  */
+#line 1699 "parse.c" /* yacc.c:1646  */
     break;
 
   case 27:
 #line 132 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newquotenode((yyvsp[0].str).s,(yyvsp[0].str).c);}
-#line 1703 "parse.c" /* yacc.c:1646  */
+#line 1705 "parse.c" /* yacc.c:1646  */
     break;
 
   case 28:
 #line 133 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 1709 "parse.c" /* yacc.c:1646  */
+#line 1711 "parse.c" /* yacc.c:1646  */
     break;
 
   case 29:
 #line 134 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fcall,(yyvsp[-3].val),(yyvsp[-1].val));}
-#line 1715 "parse.c" /* yacc.c:1646  */
+#line 1717 "parse.c" /* yacc.c:1646  */
     break;
 
   case 30:
 #line 135 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 1721 "parse.c" /* yacc.c:1646  */
+#line 1723 "parse.c" /* yacc.c:1646  */
     break;
 
   case 31:
 #line 136 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 1727 "parse.c" /* yacc.c:1646  */
+#line 1729 "parse.c" /* yacc.c:1646  */
     break;
 
   case 32:
 #line 137 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 1733 "parse.c" /* yacc.c:1646  */
+#line 1735 "parse.c" /* yacc.c:1646  */
     break;
 
   case 33:
 #line 138 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 1739 "parse.c" /* yacc.c:1646  */
+#line 1741 "parse.c" /* yacc.c:1646  */
     break;
 
   case 34:
 #line 139 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 1745 "parse.c" /* yacc.c:1646  */
+#line 1747 "parse.c" /* yacc.c:1646  */
     break;
 
   case 35:
 #line 140 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fassign,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1751 "parse.c" /* yacc.c:1646  */
+#line 1753 "parse.c" /* yacc.c:1646  */
     break;
 
   case 36:
 #line 141 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fassign,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1757 "parse.c" /* yacc.c:1646  */
+#line 1759 "parse.c" /* yacc.c:1646  */
     break;
 
   case 37:
 #line 142 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPpp,(yyvsp[-1].val),-1);}
-#line 1763 "parse.c" /* yacc.c:1646  */
+#line 1765 "parse.c" /* yacc.c:1646  */
     break;
 
   case 38:
 #line 143 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPss,(yyvsp[-1].val),-1);}
-#line 1769 "parse.c" /* yacc.c:1646  */
+#line 1771 "parse.c" /* yacc.c:1646  */
     break;
 
   case 39:
 #line 144 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPme,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1775 "parse.c" /* yacc.c:1646  */
+#line 1777 "parse.c" /* yacc.c:1646  */
     break;
 
   case 40:
 #line 145 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPde,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1781 "parse.c" /* yacc.c:1646  */
+#line 1783 "parse.c" /* yacc.c:1646  */
     break;
 
   case 41:
 #line 146 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPdre,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1787 "parse.c" /* yacc.c:1646  */
+#line 1789 "parse.c" /* yacc.c:1646  */
     break;
 
   case 42:
 #line 147 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPeuce,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1793 "parse.c" /* yacc.c:1646  */
+#line 1795 "parse.c" /* yacc.c:1646  */
     break;
 
   case 43:
 #line 148 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPmode,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1799 "parse.c" /* yacc.c:1646  */
+#line 1801 "parse.c" /* yacc.c:1646  */
     break;
 
   case 44:
 #line 149 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPsle,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1805 "parse.c" /* yacc.c:1646  */
+#line 1807 "parse.c" /* yacc.c:1646  */
     break;
 
   case 45:
 #line 150 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPsre,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1811 "parse.c" /* yacc.c:1646  */
+#line 1813 "parse.c" /* yacc.c:1646  */
     break;
 
   case 46:
 #line 151 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPpe,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1817 "parse.c" /* yacc.c:1646  */
+#line 1819 "parse.c" /* yacc.c:1646  */
     break;
 
   case 47:
 #line 152 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPse,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1823 "parse.c" /* yacc.c:1646  */
+#line 1825 "parse.c" /* yacc.c:1646  */
     break;
 
   case 48:
 #line 153 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPnb,(yyvsp[0].val),-1);}
-#line 1829 "parse.c" /* yacc.c:1646  */
+#line 1831 "parse.c" /* yacc.c:1646  */
     break;
 
   case 49:
 #line 154 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newcall("length",(yyvsp[0].val));}
-#line 1835 "parse.c" /* yacc.c:1646  */
+#line 1837 "parse.c" /* yacc.c:1646  */
     break;
 
   case 50:
 #line 155 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPor,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1841 "parse.c" /* yacc.c:1646  */
+#line 1843 "parse.c" /* yacc.c:1646  */
     break;
 
   case 51:
 #line 156 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPand,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1847 "parse.c" /* yacc.c:1646  */
+#line 1849 "parse.c" /* yacc.c:1646  */
     break;
 
   case 52:
 #line 157 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPand,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1853 "parse.c" /* yacc.c:1646  */
+#line 1855 "parse.c" /* yacc.c:1646  */
     break;
 
   case 53:
 #line 158 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPid,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1859 "parse.c" /* yacc.c:1646  */
+#line 1861 "parse.c" /* yacc.c:1646  */
     break;
 
   case 54:
 #line 159 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPeq,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1865 "parse.c" /* yacc.c:1646  */
+#line 1867 "parse.c" /* yacc.c:1646  */
     break;
 
   case 55:
 #line 160 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPne,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1871 "parse.c" /* yacc.c:1646  */
+#line 1873 "parse.c" /* yacc.c:1646  */
     break;
 
   case 56:
 #line 161 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPge,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1877 "parse.c" /* yacc.c:1646  */
+#line 1879 "parse.c" /* yacc.c:1646  */
     break;
 
   case 57:
 #line 162 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPg,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1883 "parse.c" /* yacc.c:1646  */
+#line 1885 "parse.c" /* yacc.c:1646  */
     break;
 
   case 58:
 #line 163 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPle,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1889 "parse.c" /* yacc.c:1646  */
+#line 1891 "parse.c" /* yacc.c:1646  */
     break;
 
   case 59:
 #line 164 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPl,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1895 "parse.c" /* yacc.c:1646  */
+#line 1897 "parse.c" /* yacc.c:1646  */
     break;
 
   case 60:
 #line 165 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPs,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1901 "parse.c" /* yacc.c:1646  */
+#line 1903 "parse.c" /* yacc.c:1646  */
     break;
 
   case 61:
 #line 166 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPp,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1907 "parse.c" /* yacc.c:1646  */
+#line 1909 "parse.c" /* yacc.c:1646  */
     break;
 
   case 62:
 #line 167 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPsl,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1913 "parse.c" /* yacc.c:1646  */
+#line 1915 "parse.c" /* yacc.c:1646  */
     break;
 
   case 63:
 #line 168 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPsr,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1919 "parse.c" /* yacc.c:1646  */
+#line 1921 "parse.c" /* yacc.c:1646  */
     break;
 
   case 64:
 #line 169 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPmod,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1925 "parse.c" /* yacc.c:1646  */
+#line 1927 "parse.c" /* yacc.c:1646  */
     break;
 
   case 65:
 #line 170 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPdr,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1931 "parse.c" /* yacc.c:1646  */
+#line 1933 "parse.c" /* yacc.c:1646  */
     break;
 
   case 66:
 #line 171 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPeuc,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1937 "parse.c" /* yacc.c:1646  */
+#line 1939 "parse.c" /* yacc.c:1646  */
     break;
 
   case 67:
 #line 172 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPd,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1943 "parse.c" /* yacc.c:1646  */
+#line 1945 "parse.c" /* yacc.c:1646  */
     break;
 
   case 68:
 #line 173 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPm,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1949 "parse.c" /* yacc.c:1646  */
+#line 1951 "parse.c" /* yacc.c:1646  */
     break;
 
   case 69:
 #line 174 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPpl,(yyvsp[0].val),-1);}
-#line 1955 "parse.c" /* yacc.c:1646  */
+#line 1957 "parse.c" /* yacc.c:1646  */
     break;
 
   case 70:
 #line 175 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPn,(yyvsp[0].val),-1);}
-#line 1961 "parse.c" /* yacc.c:1646  */
+#line 1963 "parse.c" /* yacc.c:1646  */
     break;
 
   case 71:
 #line 176 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPpow,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 1967 "parse.c" /* yacc.c:1646  */
+#line 1969 "parse.c" /* yacc.c:1646  */
     break;
 
   case 72:
 #line 177 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPtrans,(yyvsp[-1].val),-1);}
-#line 1973 "parse.c" /* yacc.c:1646  */
+#line 1975 "parse.c" /* yacc.c:1646  */
     break;
 
   case 73:
 #line 178 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPderiv,(yyvsp[-1].val),-1);}
-#line 1979 "parse.c" /* yacc.c:1646  */
+#line 1981 "parse.c" /* yacc.c:1646  */
     break;
 
   case 74:
 #line 179 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPfact,(yyvsp[-1].val),-1);}
-#line 1985 "parse.c" /* yacc.c:1646  */
+#line 1987 "parse.c" /* yacc.c:1646  */
     break;
 
   case 75:
 #line 180 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fmatcoeff,(yyvsp[-1].val),(yyvsp[0].val));}
-#line 1991 "parse.c" /* yacc.c:1646  */
+#line 1993 "parse.c" /* yacc.c:1646  */
     break;
 
   case 76:
 #line 181 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 1997 "parse.c" /* yacc.c:1646  */
+#line 1999 "parse.c" /* yacc.c:1646  */
     break;
 
   case 77:
 #line 182 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newtag((yyvsp[-2].val),(yyvsp[0].str).s,(yyvsp[0].str).c);}
-#line 2003 "parse.c" /* yacc.c:1646  */
+#line 2005 "parse.c" /* yacc.c:1646  */
     break;
 
   case 78:
 #line 183 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[-1].val);}
-#line 2009 "parse.c" /* yacc.c:1646  */
+#line 2011 "parse.c" /* yacc.c:1646  */
     break;
 
   case 79:
 #line 186 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnodecom(Fentry,newentry((yyvsp[0].str).s),-1,(yyvsp[0].str).c);}
-#line 2015 "parse.c" /* yacc.c:1646  */
+#line 2017 "parse.c" /* yacc.c:1646  */
     break;
 
   case 80:
 #line 187 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fmatcoeff,(yyvsp[-1].val),(yyvsp[0].val));}
-#line 2021 "parse.c" /* yacc.c:1646  */
+#line 2023 "parse.c" /* yacc.c:1646  */
     break;
 
   case 81:
 #line 188 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newtag((yyvsp[-2].val),(yyvsp[0].str).s,(yyvsp[0].str).c);}
-#line 2027 "parse.c" /* yacc.c:1646  */
+#line 2029 "parse.c" /* yacc.c:1646  */
     break;
 
   case 82:
 #line 191 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 2033 "parse.c" /* yacc.c:1646  */
+#line 2035 "parse.c" /* yacc.c:1646  */
     break;
 
   case 83:
 #line 192 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fmatrixelts,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 2039 "parse.c" /* yacc.c:1646  */
+#line 2041 "parse.c" /* yacc.c:1646  */
     break;
 
   case 84:
 #line 195 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fmatrixlines,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 2045 "parse.c" /* yacc.c:1646  */
+#line 2047 "parse.c" /* yacc.c:1646  */
     break;
 
   case 85:
 #line 196 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fmatrixlines,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 2051 "parse.c" /* yacc.c:1646  */
+#line 2053 "parse.c" /* yacc.c:1646  */
     break;
 
   case 86:
 #line 199 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fvec,-1,-1);}
-#line 2057 "parse.c" /* yacc.c:1646  */
+#line 2059 "parse.c" /* yacc.c:1646  */
     break;
 
   case 87:
 #line 200 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPrange,(yyvsp[-3].val),(yyvsp[-1].val));}
-#line 2063 "parse.c" /* yacc.c:1646  */
+#line 2065 "parse.c" /* yacc.c:1646  */
     break;
 
   case 88:
 #line 201 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fmat,-1,-1);}
-#line 2069 "parse.c" /* yacc.c:1646  */
+#line 2071 "parse.c" /* yacc.c:1646  */
     break;
 
   case 89:
 #line 202 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fvec,(yyvsp[-1].val),-1);}
-#line 2075 "parse.c" /* yacc.c:1646  */
+#line 2077 "parse.c" /* yacc.c:1646  */
     break;
 
   case 90:
 #line 203 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fmat,(yyvsp[-1].val),-1);}
-#line 2081 "parse.c" /* yacc.c:1646  */
+#line 2083 "parse.c" /* yacc.c:1646  */
     break;
 
   case 91:
 #line 204 "parse.y" /* yacc.c:1646  */
     {YYABORT;}
-#line 2087 "parse.c" /* yacc.c:1646  */
+#line 2089 "parse.c" /* yacc.c:1646  */
     break;
 
   case 92:
 #line 207 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Flistarg,(yyvsp[0].val),(yyvsp[-3].val));}
-#line 2093 "parse.c" /* yacc.c:1646  */
+#line 2095 "parse.c" /* yacc.c:1646  */
     break;
 
   case 93:
 #line 210 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPcompr,(yyvsp[0].val),-2);}
-#line 2099 "parse.c" /* yacc.c:1646  */
+#line 2101 "parse.c" /* yacc.c:1646  */
     break;
 
   case 94:
 #line 211 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall3(OPcompr,(yyvsp[-2].val),-2,(yyvsp[0].val));}
-#line 2105 "parse.c" /* yacc.c:1646  */
+#line 2107 "parse.c" /* yacc.c:1646  */
     break;
 
   case 95:
 #line 212 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall(OPcomprc,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 2111 "parse.c" /* yacc.c:1646  */
+#line 2113 "parse.c" /* yacc.c:1646  */
     break;
 
   case 96:
 #line 213 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newopcall3(OPcomprc,(yyvsp[-4].val),(yyvsp[0].val),(yyvsp[-2].val));}
-#line 2117 "parse.c" /* yacc.c:1646  */
+#line 2119 "parse.c" /* yacc.c:1646  */
     break;
 
   case 97:
 #line 216 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=addcurrexpr((yyvsp[-1].val),(yyvsp[-3].val));}
-#line 2123 "parse.c" /* yacc.c:1646  */
+#line 2125 "parse.c" /* yacc.c:1646  */
     break;
 
   case 98:
 #line 219 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 2129 "parse.c" /* yacc.c:1646  */
+#line 2131 "parse.c" /* yacc.c:1646  */
     break;
 
   case 99:
 #line 220 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fvararg,(yyvsp[-3].val),-1);}
-#line 2135 "parse.c" /* yacc.c:1646  */
+#line 2137 "parse.c" /* yacc.c:1646  */
     break;
 
   case 100:
 #line 221 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Frefarg,(yyvsp[0].val),-1);}
-#line 2141 "parse.c" /* yacc.c:1646  */
+#line 2143 "parse.c" /* yacc.c:1646  */
     break;
 
   case 101:
 #line 222 "parse.y" /* yacc.c:1646  */
     {if (!once) { yyerrok; s_errors.n--;} once=1;}
-#line 2147 "parse.c" /* yacc.c:1646  */
+#line 2149 "parse.c" /* yacc.c:1646  */
     break;
 
   case 102:
 #line 223 "parse.y" /* yacc.c:1646  */
     {once=0; (yyval.val)=newopcall(OPcat,(yyvsp[-3].val),(yyvsp[0].val));}
-#line 2153 "parse.c" /* yacc.c:1646  */
+#line 2155 "parse.c" /* yacc.c:1646  */
     break;
 
   case 103:
 #line 226 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=(yyvsp[0].val);}
-#line 2159 "parse.c" /* yacc.c:1646  */
+#line 2161 "parse.c" /* yacc.c:1646  */
     break;
 
   case 104:
 #line 227 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Flistarg,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 2165 "parse.c" /* yacc.c:1646  */
+#line 2167 "parse.c" /* yacc.c:1646  */
     break;
 
   case 105:
 #line 230 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnodecom(Ffunction,newentry((yyvsp[-3].str).s),(yyvsp[-1].val),(yyvsp[-3].str).c);}
-#line 2171 "parse.c" /* yacc.c:1646  */
+#line 2173 "parse.c" /* yacc.c:1646  */
     break;
 
   case 106:
 #line 233 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnodecom(Ffunction,newmember((yyvsp[0].str).s),(yyvsp[-2].val),(yyvsp[0].str).c);}
-#line 2177 "parse.c" /* yacc.c:1646  */
+#line 2179 "parse.c" /* yacc.c:1646  */
     break;
 
   case 107:
 #line 237 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fdeffunc,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 2183 "parse.c" /* yacc.c:1646  */
+#line 2185 "parse.c" /* yacc.c:1646  */
     break;
 
   case 108:
 #line 239 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Fdeffunc,(yyvsp[-2].val),(yyvsp[0].val));}
-#line 2189 "parse.c" /* yacc.c:1646  */
+#line 2191 "parse.c" /* yacc.c:1646  */
     break;
 
   case 109:
 #line 240 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Flambda, (yyvsp[-2].val),(yyvsp[0].val));}
-#line 2195 "parse.c" /* yacc.c:1646  */
+#line 2197 "parse.c" /* yacc.c:1646  */
     break;
 
   case 110:
 #line 241 "parse.y" /* yacc.c:1646  */
     {(yyval.val)=newnode(Flambda, (yyvsp[-2].val),(yyvsp[0].val));}
-#line 2201 "parse.c" /* yacc.c:1646  */
+#line 2203 "parse.c" /* yacc.c:1646  */
     break;
 
 
-#line 2205 "parse.c" /* yacc.c:1646  */
+#line 2207 "parse.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
